Arguments
survey.data
the dataframe with the survey results
known.popns
if not NULL, a vector whose entries are the size of the known
populations, and whose names are the variable names in the dataset
corresponding to each one. if NULL, then assume that the survey.data
dataframe has an attribute called 'known.popns' containing this vector.
total.popn.size
the size of the entire population. if NULL,
this function returns proportions; if not NULL, it
returns absolute numbers (ie, the proportions * total popn size)
missing
if "ignore", then proceed with the analysis without
doing anything about missing values. if "complete.obs"
then, for each row, use only the known populations
that have no missingness for the
computations. care must be taken in using this second option
verbose
if TRUE, print messages to the screen